<?php
/**
 * @file
 *   Hook documentation for the "Follow Me" module.
 *
 *   <p>© 2014-2017 Red Bottle Design, LLC.</p>
 *
 * @author Guy Paddock (guy.paddock@redbottledesign.com)
 */

/**
 * Provides a way to expose the location of the current site visitor within
 * the site.
 *
 * The location is expressed in relation to the type of entity or view that's
 * being displayed. This means that the context consists of an entity type
 * (like "taxonomy_term" or "node") or object type (like "view"); and values
 * and a callback that can be used to load that entity or object type.
 *
 * @return array
 *   An array, keyed by the type of object. The value of each element must be an
 *   array containing the following values:
 *     - id:
 *       The unique identifier for the object.
 *     - bundle:
 *       The bundle or other sub-type of object. This is included for
 *       performance reasons.
 *     - callback:
 *       The callback for de-serializing the object from the context.
 *     - extra_callback_args:
 *       An optional array of additional args that will be passed to the
 *       deserialization callback, beyond the object ID.
 */
function hook_follow_me_context() {
  // Example taken from fm_views_follow_me_context().
  $context  = array();
  $view     = views_get_current_view();

  if (!empty($view)) {
    $context = array(
      'view' => array(
        'id'        => $view->name,
        'bundle'    => $view->name,
        'args'      => $view->argument,
        'callback'  => 'views_get_view',
      ),
    );
  }

  return $context;
}

/**
 * Provides a way for modules to prune a Follow Me trail before it is persisted.
 *
 * @param array $variables
 *   An array containing the specified values:
 *    - original: An array containing the original, un-pruned components of the
 *      trail.
 *    - pruned: A reference to the pruned components of the trail. This array
 *      is modified by this alter hook.
 */
function hook_follow_me_prune_alter(array &$variables) {
  // Removes the oldest component of the trail
  $variables['pruned'] = array_slice($variables['pruned'], -1);
}
